/*
 * Project name:
     Lcd_Test (Demonstration of the LCD library routines)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History:
     20110414:
       - initial release (FJ);
 * Description:
     This code demonstrates how to use LCD 4-bit library. LCD is first
     initialized, then some text is written, then the text is moved.
 * Test configuration:
     MCU:             P18F8520
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39609b.pdf
     Dev.Board:       UNI-DS6 - ac:LCD
                      http://www.mikroe.com/eng/products/view/669/uni-ds6-development-system/
     Oscillator:      HS, 10.0 MHz
     Ext. Modules:    LCD 2x16
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
 * NOTES:
     - Turn on LCD/GLCD Control switches at SW15.5 and SW15.6 (board specific).
     - Turn on LCD Data switches at SW17 (board specific).
     - Turn on LCD backlight at SW18.7 (board specific).
*/

// LCD module connections
sbit LCD_RS at LATB2_bit;  // for writing to output pin always use latch (PIC18 family)
sbit LCD_EN at LATB5_bit;  // for writing to output pin always use latch (PIC18 family)
sbit LCD_D4 at LATC4_bit;  // for writing to output pin always use latch (PIC18 family)
sbit LCD_D5 at LATC5_bit;  // for writing to output pin always use latch (PIC18 family)
sbit LCD_D6 at LATC6_bit;  // for writing to output pin always use latch (PIC18 family)
sbit LCD_D7 at LATC7_bit;  // for writing to output pin always use latch (PIC18 family)

sbit LCD_RS_Direction at TRISB2_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISC4_bit;
sbit LCD_D5_Direction at TRISC5_bit;
sbit LCD_D6_Direction at TRISC6_bit;
sbit LCD_D7_Direction at TRISC7_bit;
// End LCD module connections

char txt1[] = "mikroElektronika";
char txt2[] = "UNI-DS6";
char txt3[] = "Lcd4bit";
char txt4[] = "example";

char i;                              // Loop variable

void Move_Delay() {                  // Function used for text moving
  Delay_ms(500);                     // You can change the moving speed here
}

void main(){

  ADCON1 |= 0x0F;                    // Configure AN pins as digital
  CMCON  |= 7;                       // Disable comparators

  Lcd_Init();                        // Initialize LCD
  Lcd_Cmd(_LCD_CLEAR);               // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);          // Cursor off

  Lcd_Out(1,6,txt3);                 // Write text in first row
  Lcd_Out(2,6,txt4);                 // Write text in second row
  Delay_ms(2000);
  Lcd_Cmd(_LCD_CLEAR);               // Clear display

  Lcd_Out(1,1,txt1);                 // Write text in first row
  Lcd_Out(2,5,txt2);                 // Write text in second row
  Delay_ms(2000);

  // Moving text
  for(i=0; i<4; i++) {               // Move text to the right 4 times
    Lcd_Cmd(_LCD_SHIFT_RIGHT);
    Move_Delay();
  }

  while(1) {                         // Endless loop
    for(i=0; i<7; i++) {             // Move text to the left 7 times
      Lcd_Cmd(_LCD_SHIFT_LEFT);
      Move_Delay();
    }

    for(i=0; i<7; i++) {             // Move text to the right 7 times
      Lcd_Cmd(_LCD_SHIFT_RIGHT);
      Move_Delay();
    }

  }
}